import { getCurrentInstance } from "@vue/composition-api";
import ziggy from "ziggy-js";
/**
 * Vue Inertia Composable
 *
 * @license MIT
 * @author Logue {@link logue@hotmail.co.jp}
 * @copyright 2022 Masashi Yoshikawa {@link https://logue.dev/} All rights reserved.
 * @see {@link https://github.com/logue/vue-inertia-composable}
 */
function useHeadManager() {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$headManager;
  } else {
    warn();
  }
  return void 0;
}
function usePage() {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$page;
  } else {
    warn();
  }
  return void 0;
}
function useInertia() {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$inertia;
  } else {
    warn();
  }
  return void 0;
}
function route(name, params, absolute, config) {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.route(name, params, absolute, config);
  }
  return ziggy(name, params, absolute, config);
}
function warn() {
  console.warn(`[Inertia Composable] getCurrentInstance() returned null. Method must be called at the top of a setup() function.`);
}
export { route, useHeadManager, useInertia, usePage };
